@@ -4,8 +4,12 @@ from .formatted_console_output import (
     TextFormat,
     FormattedPhrase,
     CustomColor,
+    ErrorType,
     output_formatted_message,
-    output_many_format_message
+    output_error_message,
+    output_many_format_message,
+    log_exception_stacktrace,
+    RESET,
 )
 
 __all__ = [
@@ -14,6 +18,10 @@ __all__ = [
     "TextFormat",
     "FormattedPhrase",
     "CustomColor",
+    "ErrorType",
     "output_formatted_message",
-    "output_many_format_message"
+    "output_error_message",
+    "output_many_format_message",
+    "log_exception_stacktrace",
+    "RESET",
 ]
